==> gimp-plugin-interpolate-0.2.tar.gz: gimp-plugin-interpolate-0.2/src/main.c <==
/*
 * This is copyrighted software.  Originally uploaded at the GIMP Plugin
 * Registry (http://registry.gimp.org/).  This is to be distributed
 * ("conveyed") under the terms of version 3 of the GNU General Public License
 * (no other version, see the file "COPYING" for details).  THERE IS NO IMPLIED
 * WARRANTY FOR THIS PROGRAM.  USE AT YOUR OWN RISK.  For inquiries, email the
 * author at stamit@stamit.gr .  You may not remove this notice.
 */
#include "config.h"

#include <string.h>

#include <libgimp/gimp.h>
#include <libgimp/gimpui.h>

#include "main.h"
#include "interface.h"
#include "render.h"

#include "plugin-intl.h"


/*  Constants  */

#define PROCEDURE_NAME   "gimp_plugin_interpolate"

#define DATA_KEY_VALS    "plug_in_interpolate"
#define DATA_KEY_UI_VALS "plug_in_interpolate_ui"

#define PARASITE_KEY     "plug-in-interpolate-options"


/*  Local function prototypes  */

static void query(void);
static void run(const gchar *name, gint nparams, const GimpParam *param, gint *nreturn_vals, GimpParam **return_vals);


/*  Local variables  */

const PlugInVals default_vals = {
	-1,  /* chanindex */
	FALSE,  /* usesel */
	FALSE,  /* halfsel */

	64,  /* window */
	4,  /* sigma */
	KERNEL_INVNTH,  /* kernel */
	FALSE,  /* newlayer */

	TRUE,  /* calcderivs */
	2,  /* linwindow */
	TRUE,  /* lincenter */
	FALSE,  /* linsymwin */
	3.0,  /* linsigma */
	KERNEL_SQUARE,  /* linkernel */
	//FALSE,  /* linnewlayer */

	TRUE,  /* changesel */
	0,  /* lowthres */
	0.01,  /* highthres */
	FALSE,  /* logthres */
	FALSE,  /* multmask */
};

const PlugInUIVals default_ui_vals = {
	FALSE,
};

static PlugInVals vals;
static PlugInUIVals ui_vals;


GimpPlugInInfo PLUG_IN_INFO = {
	NULL,  /* init_proc  */
	NULL,  /* quit_proc  */
	query, /* query_proc */
	run,   /* run_proc   */
};

MAIN ()

static void query(void) {
	gchar *help_path;
	gchar *help_uri;

	static GimpParamDef args[] = {
		{GIMP_PDB_INT32, "run_mode",
		 "Interactive, non-interactive"},
		{GIMP_PDB_IMAGE, "image", "Input image"},
		{GIMP_PDB_DRAWABLE, "drawable", "Input drawable"},
		/*{ GIMP_PDB_INT32,    "dummy",      "dummy1"                          },
		   { GIMP_PDB_INT32,    "dummy",      "dummy2"                          },
		   { GIMP_PDB_INT32,    "dummy",      "dummy3"                          },
		   { GIMP_PDB_INT32,    "seed",       "Seed value (used only if randomize is FALSE)" },
		   { GIMP_PDB_INT32,    "randomize",  "Use a random seed (TRUE, FALSE)" } */
	};

	gimp_plugin_domain_register(PLUGIN_NAME, LOCALEDIR);

	help_path = g_build_filename(DATADIR, "help", NULL);
	help_uri = g_filename_to_uri(help_path, NULL, NULL);
	g_free(help_path);

	//gimp_plugin_help_register
	//    ("http://developer.gimp.org/plug-in-template/help", help_uri);

	gimp_install_procedure(PROCEDURE_NAME,
			       "Simple interpolatin",
			       "Does simple interpolation using weighted averages (\"guesses\" pixel values from surroundings)",
			       "stamit@stamit.gr",
			       "stamit@stamit.gr",
			       "2010",
			       N_("_Simple Interpolation..."),
			       "RGB*, GRAY*",
			       GIMP_PLUGIN,
			       G_N_ELEMENTS(args), 0, args, NULL);

	gimp_plugin_menu_register(PROCEDURE_NAME, "<Image>/Filters/Generic/");
}

static void run(const gchar *name,
		gint n_params,
		const GimpParam *param,
		gint *nreturn_vals, GimpParam **return_vals)
{
	static GimpParam values[1];
	GimpDrawable *drawable;
	gint32 image_ID;
	GimpRunMode run_mode;
	GimpPDBStatusType status = GIMP_PDB_SUCCESS;

	*nreturn_vals = 1;
	*return_vals = values;

	/*  Initialize i18n support  */
	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
#endif
	textdomain(GETTEXT_PACKAGE);

	run_mode = param[0].data.d_int32;
	image_ID = param[1].data.d_int32;
	drawable = gimp_drawable_get(param[2].data.d_drawable);

	/*  Initialize with default values  */
	vals = default_vals;
	ui_vals = default_ui_vals;

	if (strcmp(name, PROCEDURE_NAME) != 0) {
		status = GIMP_PDB_CALLING_ERROR;

	} else switch (run_mode) {

	case GIMP_RUN_NONINTERACTIVE:
		if (n_params != 8) {
			status = GIMP_PDB_CALLING_ERROR;
		} else {
			//if (vals.random_seed)
			//vals.seed = g_random_int ();
		}
		break;

	case GIMP_RUN_INTERACTIVE:
		/*  Possibly retrieve data  */
		gimp_get_data(DATA_KEY_VALS, &vals);
		gimp_get_data(DATA_KEY_UI_VALS, &ui_vals);

		if (!dialog(image_ID, drawable, &vals, &ui_vals)) {
			status = GIMP_PDB_CANCEL;
		}
		break;

	case GIMP_RUN_WITH_LAST_VALS:
		/*  Possibly retrieve data  */
		gimp_get_data(DATA_KEY_VALS, &vals);

		//if (vals.random_seed)
		//vals.seed = g_random_int ();
		break;

	default:
		break;
	}

	if (status == GIMP_PDB_SUCCESS) {
		render(image_ID, drawable, &vals);

		if (run_mode != GIMP_RUN_NONINTERACTIVE)
			gimp_displays_flush();

		if (run_mode == GIMP_RUN_INTERACTIVE) {
			gimp_set_data(DATA_KEY_VALS, &vals, sizeof(vals));
			gimp_set_data(DATA_KEY_UI_VALS, &ui_vals,
				      sizeof(ui_vals));
		}

		gimp_drawable_detach(drawable);
	}

	values[0].type = GIMP_PDB_STATUS;
	values[0].data.d_status = status;
}

==> gimp-plugin-interpolate-0.3.tar.gz: gimp-plugin-interpolate-0.3/src/main.c <==
/*
 * This is copyrighted software.  Originally uploaded at the GIMP Plugin
 * Registry (http://registry.gimp.org/).  This is to be distributed
 * ("conveyed") under the terms of version 3 of the GNU General Public License
 * (no other version, see the file "COPYING" for details).  THERE IS NO IMPLIED
 * WARRANTY FOR THIS PROGRAM.  USE AT YOUR OWN RISK.  For inquiries, email the
 * author at stamit@stamit.gr .  You may not remove this notice.
 */
#include "config.h"

#include <string.h>

#include <libgimp/gimp.h>
#include <libgimp/gimpui.h>

#include "main.h"
#include "interface.h"
#include "render.h"

#include "plugin-intl.h"


/*  Constants  */

#define PROCEDURE_NAME   "gimp_plugin_interpolate"

#define DATA_KEY_VALS    "plug_in_interpolate"
#define DATA_KEY_UI_VALS "plug_in_interpolate_ui"

#define PARASITE_KEY     "plug-in-interpolate-options"


/*  Local function prototypes  */

static void query(void);
static void run(const gchar *name, gint nparams, const GimpParam *param, gint *nreturn_vals, GimpParam **return_vals);


/*  Local variables  */

const PlugInVals default_vals = {
	-1,  /* chanindex */
	FALSE,  /* usesel */
	FALSE,  /* halfsel */

	64,  /* window */
	3.0,  /* sigma */
	KERNEL_INVNTH,  /* kernel */
	FALSE,  /* newlayer */

	TRUE,  /* slopes */
	TRUE,  /* leastsq */
	2,  /* linwindow */
	//TRUE,  /* lincenter */
	FALSE,  /* linsymwin */
	3.0,  /* linsigma */
	KERNEL_SQUARE,  /* linkernel */
	FALSE,  /* linnewlayer */

	FALSE,  /* changesel */
	0,  /* lowthres */
	0.01,  /* highthres */
	FALSE,  /* logthres */
	FALSE,  /* multmask */
};

const PlugInUIVals default_ui_vals = {
	FALSE,
};

static PlugInVals vals;
static PlugInUIVals ui_vals;


GimpPlugInInfo PLUG_IN_INFO = {
	NULL,  /* init_proc  */
	NULL,  /* quit_proc  */
	query, /* query_proc */
	run,   /* run_proc   */
};

MAIN ()

static void query(void) {
	gchar *help_path;
	gchar *help_uri;

	static GimpParamDef args[] = {
		{GIMP_PDB_INT32, "run_mode",
		 "Interactive, non-interactive"},
		{GIMP_PDB_IMAGE, "image", "Input image"},
		{GIMP_PDB_DRAWABLE, "drawable", "Input drawable"},
		/*{ GIMP_PDB_INT32,    "dummy",      "dummy1"                          },
		   { GIMP_PDB_INT32,    "dummy",      "dummy2"                          },
		   { GIMP_PDB_INT32,    "dummy",      "dummy3"                          },
		   { GIMP_PDB_INT32,    "seed",       "Seed value (used only if randomize is FALSE)" },
		   { GIMP_PDB_INT32,    "randomize",  "Use a random seed (TRUE, FALSE)" } */
	};

	gimp_plugin_domain_register(PLUGIN_NAME, LOCALEDIR);

	help_path = g_build_filename(DATADIR, "help", NULL);
	help_uri = g_filename_to_uri(help_path, NULL, NULL);
	g_free(help_path);

	//gimp_plugin_help_register
	//    ("http://developer.gimp.org/plug-in-template/help", help_uri);

	gimp_install_procedure(PROCEDURE_NAME,
			       "Simple interpolatin",
			       "Does simple interpolation using weighted averages (\"guesses\" pixel values from surroundings)",
			       "stamit@stamit.gr",
			       "stamit@stamit.gr",
			       "2010",
			       N_("_Simple Interpolation..."),
			       "RGB*, GRAY*",
			       GIMP_PLUGIN,
			       G_N_ELEMENTS(args), 0, args, NULL);

	gimp_plugin_menu_register(PROCEDURE_NAME, "<Image>/Filters/Generic/");
}

static void run(const gchar *name,
		gint n_params,
		const GimpParam *param,
		gint *nreturn_vals, GimpParam **return_vals)
{
	static GimpParam values[1];
	GimpDrawable *drawable;
	gint32 image_ID;
	GimpRunMode run_mode;
	GimpPDBStatusType status = GIMP_PDB_SUCCESS;

	*nreturn_vals = 1;
	*return_vals = values;

	/*  Initialize i18n support  */
	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
#endif
	textdomain(GETTEXT_PACKAGE);

	run_mode = param[0].data.d_int32;
	image_ID = param[1].data.d_int32;
	drawable = gimp_drawable_get(param[2].data.d_drawable);

	/*  Initialize with default values  */
	vals = default_vals;
	ui_vals = default_ui_vals;

	if (strcmp(name, PROCEDURE_NAME) != 0) {
		status = GIMP_PDB_CALLING_ERROR;

	} else switch (run_mode) {

	case GIMP_RUN_NONINTERACTIVE:
		if (n_params != 8) {
			status = GIMP_PDB_CALLING_ERROR;
		} else {
			//if (vals.random_seed)
			//vals.seed = g_random_int ();
		}
		break;

	case GIMP_RUN_INTERACTIVE:
		/*  Possibly retrieve data  */
		gimp_get_data(DATA_KEY_VALS, &vals);
		gimp_get_data(DATA_KEY_UI_VALS, &ui_vals);

		if (!dialog(image_ID, drawable, &vals, &ui_vals)) {
			status = GIMP_PDB_CANCEL;
		}
		break;

	case GIMP_RUN_WITH_LAST_VALS:
		/*  Possibly retrieve data  */
		gimp_get_data(DATA_KEY_VALS, &vals);

		//if (vals.random_seed)
		//vals.seed = g_random_int ();
		break;

	default:
		break;
	}

	if (status == GIMP_PDB_SUCCESS) {
		render(image_ID, drawable, &vals);

		if (run_mode != GIMP_RUN_NONINTERACTIVE)
			gimp_displays_flush();

		if (run_mode == GIMP_RUN_INTERACTIVE) {
			gimp_set_data(DATA_KEY_VALS, &vals, sizeof(vals));
			gimp_set_data(DATA_KEY_UI_VALS, &ui_vals,
				      sizeof(ui_vals));
		}

		gimp_drawable_detach(drawable);
	}

	values[0].type = GIMP_PDB_STATUS;
	values[0].data.d_status = status;
}
